/*
 * pushButton.cpp - Library for Push Buttons without using Delay
 * Created by Ítalo Coelho, January 3, 2020
 */

#include "Arduino.h"
#include "pushButton.h"

#define tempoDebounce 50

pushButton::pushButton(int pin)
{
  pinMode(pin, INPUT_PULLUP);
  _pin = pin;
}

bool pushButton::wasPressed()
{
  bool answer = false;

  static bool estadoAtual = HIGH;
  static bool estadoAnterior = HIGH;
  static unsigned long delayBotao = 0;

  if( (millis() - delayBotao) >  tempoDebounce )
  {
    estadoAtual = digitalRead(_pin);
    if(!estadoAtual && estadoAnterior)
    {
      answer = true;
      delayBotao = millis();
    }
    estadoAnterior = estadoAtual;
  }

  return answer;
}

bool pushButton::retentionState()
{
  static bool answer = false;

  static bool estadoAtual = HIGH;
  static bool estadoAnterior = HIGH;
  static unsigned long delayBotao = 0;

  if( (millis() - delayBotao) >  tempoDebounce )
  {
    estadoAtual = digitalRead(_pin);
    if(!estadoAtual && estadoAnterior)
    {
      answer = !answer;
      delayBotao = millis();
    }
    estadoAnterior = estadoAtual;
  }

  return answer;
}
